Learn R Programming

WordOfMouth (version 1.2.0)

WoMCampaign-class: Class WoMCampaign

Description

This class represents a WoM campaign that is performed on a given network to promote a durable good with no variable costs.

Arguments

Slots

network

(WoMNetwork) The network to which the WoM campaign is applied.

seedingSize

(numeric) Number of consumers who are initially informed about the good by the firm.

forwardProbability

(numeric) Probability at which a consumer forwards information about the good to others.

informationCosts

(numeric) Costs to information one consumer about the good.

Objects from the Class

Objects can be created by calls of the form new("WoMCampaign", ...). This S4 class describes WoMNetwork objects.

Examples

Run this code

network <- new("WoMNetwork", size = 1000, avgConnections = 5)
campaign <- new("WoMCampaign", network = network, seedingSize = 10, forwardProbability = 0.2)
print(campaign)

Run the code above in your browser using DataLab