Learn R Programming

WordOfMouth (version 1.2.0)

WordOfMouth-package: Estimates Economic Variables for Word-of-Mouth-Campaigns

Description

This packages provides classes, methods and functions for modeling Word-of-Mouth-campaigns. General model assumptions are:

  • monopoly market

  • no variable costs

  • network is the mean-field case of percolation

  • only those persons who bought a product will forward information about it

Arguments

Details

Package:WordOfMouth
Type:Package
Version:1.2.0
Date:2025-06-02
License:GPL-3
Depends:R (>= 3.0.1), methods