Learn R Programming

WordOfMouth (version 1.2.0)

compareToFIMarket: Compares the welfare of the WoM campaign to that of a fully informed market

Description

Compares the welfare of the WoM campaign to the welfare of a fully informed market assuming a uniformly distributed willingness to pay.

Usage

compareToFIMarket(campaign)

Value

Data frame containing the profit-maximizing price, the resulting demand, profit, consumer surplus and economic welfare for a fully informed market and a WoM market.

Arguments

campaign

Word-of-Mouth campaign as instance of class WoMCampaign.

See Also

computeOptimalPrice computeProfit computeConsumerSurplus

Examples

Run this code

network <- new("WoMNetwork", size = 1000, avgConnections = 5)
campaign <- new("WoMCampaign", network = network, seedingSize = 10, forwardProbability = 0.2)
comparison <- compareToFIMarket(campaign)
print(comparison)

Run the code above in your browser using DataLab