Learn R Programming

WordOfMouth (version 1.2.0)

computeInformationCostsThreshold: Computes the information costs threshold

Description

Computes the information costs that need to be surpassed in order to generate a higher profit than in a transparent market.

Usage

computeInformationCostsThreshold(campaign)

Value

Information costs in [0; 1] that need to be surpassed in order to generate a higher profit than in a transparent market.

Arguments

campaign

Word-of-Mouth campaign as instance of class WoMCampaign.

See Also

computeOptimalPrice computeProfit

Examples

Run this code

network <- new("WoMNetwork", size = 1000, avgConnections = 5)
campaign <- new("WoMCampaign", network = network, seedingSize = 10, forwardProbability = 0.2)
threshold <- computeInformationCostsThreshold(campaign)
print(threshold)

Run the code above in your browser using DataLab