powered by
WoMCampaign
This class represents a WoM campaign that is performed on a given network to promote a durable good with no variable costs.
network
(WoMNetwork) The network to which the WoM campaign is applied.
seedingSize
(numeric) Number of consumers who are initially informed about the good by the firm.
forwardProbability
(numeric) Probability at which a consumer forwards information about the good to others.
informationCosts
(numeric) Costs to information one consumer about the good.
Objects can be created by calls of the form new("WoMCampaign", ...). This S4 class describes WoMNetwork objects.
new("WoMCampaign", ...)
WoMNetwork
Michael Scholz michael.scholz@th-deg.de
Thomas Woehner Thomas.Woehner@eah-jena.de
Ralf Peters ralf.peters@wiwi.uni-halle.de
network <- new("WoMNetwork", size = 1000, avgConnections = 5) campaign <- new("WoMCampaign", network = network, seedingSize = 10, forwardProbability = 0.2) print(campaign)
Run the code above in your browser using DataLab